@@ -1,15 +1,15 @@
 import argparse
 import os
 
-from .client import ZeroClient
+from .client_server.client import ZeroClient
 
 
 def generate_client_code_and_save(host, port, directory, overwrite_dir=False):
     zero_client = ZeroClient(host, port)
     code = zero_client.call("get_rpc_contract", [host, port])
 
-    if not code:
-        print(f"Cannot connect to {host}:{port}")
+    if isinstance(code, dict) and "__zerror__failed_to_generate_client_code" in code:
+        print(f"Failed to generate client code: {code['__zerror__failed_to_generate_client_code']}")
         return
 
     if directory != ".":
@@ -22,7 +22,7 @@ def generate_client_code_and_save(host, port, directory, overwrite_dir=False):
                 return
 
     with open(directory + "/rpc_client.py", "w") as f:
-        f.write(code)  # type: ignore
+        f.write(code)
 
 
 if __name__ == "__main__":  # pragma: no cover
